-- License CC0 (Creative Commons license) (c) darkfrei, 2021

function new_face()
	local face = {}
	local max = 0
	
	for i = 1, side/2 do
		face[i] = {}
--		print('i: '..i)
		for j = 1, side do
			local value = math.random ()
--			local a = 0.3
			local a = math.random()/2
			value = a + (1-a)*(value^0.5)
--			local t2 = (i-side/2)^2
--			local t3 = (j-side/2)^2
			local t2 = math.abs(i-side/2)/(side/2)
			local t3 = math.abs(j-side/2)/(side/2)
			
			value = value - 0.8*t2 - 0.5*t3
			max = math.max(max, value)
			face[i][j] = value
		end
	end
	for i = side/2+1, side do
		face[i] = {}
		for j = 1, side do
			
			local i2 = side+1-i
			
			local value = face[i2][j]
			value = value / max
			face[i][j] = value
			face[i2][j] = value
		end
	end
	return face
end

function new_faces()
	width, height = love.graphics.getDimensions( )
	faces = {}
	print ('width:'..width..' size:'..size..' side:'..side..' size*side:'..size*side)
	for i = 1, (width)/(side*(size+1)) do
		for j = 1, height/(side*(size+1.75)) do
--		local y = size*(size+1)
			local face = new_face()
			local x = (i-1)*(side*(size+1))
			local y = (j  )*(side*(size+1))
			faces[#faces+1] = {face=face, x=x, y=y}
		end
	end
	print('faces: '..#faces)
end

function change_background ()
	c_bg = not c_bg
	if c_bg then
		local background_color = {132/255, 193/255, 238/255}
		love.graphics.setBackgroundColor( background_color )
	else
		local background_color = {0/255, 0/255, 10/255}
		love.graphics.setBackgroundColor( background_color )
	end
end

function love.load()
	local ddwidth, ddheight = love.window.getDesktopDimensions( display )
	if ddheight > 1080 then
		print('ddheight: ' .. ddheight)
		love.window.setMode(1920, 1080, {resizable=true, borderless=false})
	else
		love.window.setMode(ddwidth, ddheight-200, {resizable=true, borderless=false})
	end

	change_background ()
	
	size = 6 -- in pixels
	side = 10 -- side of square
	
	

	new_faces()
	
	print('faces: '..#faces)
end

 
function love.update(dt)
	
end


function draw_face (face, x, y)
	for i, js in pairs (face) do
		for j, value in pairs (js) do
			local c = value
			love.graphics.setColor (c,c,c)
			love.graphics.rectangle('fill', x+i*size, y+j*size, size,size)
		end
	end
end

function love.draw()
	love.graphics.setColor(1,1,1)
	love.graphics.print('faces: '..#faces,0,0)
	love.graphics.print('side: '..side,0,20)
	love.graphics.print('size: '..size,0,40)
	for i, f in pairs (faces) do
		draw_face (f.face, f.x, f.y)
	end
end

function love.keypressed(key, scancode, isrepeat)
	if key == "space" then
		new_faces()
	elseif key == "w" then
		side = side + 2
		new_faces()
	elseif key == "s" then
		side = side - 2
		side = math.max(side, 6)
		new_faces()
	elseif key == "q" then
		size = size + 1
--		new_faces()
	elseif key == "a" then
		size = size - 1
--		new_faces()
	elseif key == "z" then
		change_background ()
	elseif key == "escape" then
		love.event.quit()
	end
end